<?php
namespace MascotCoreTranxpress\Widgets\FeatureBlock\Skins;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Skin_Base as Elementor_Skin_Base;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Skin_Style2 extends Elementor_Skin_Base {

	protected function _register_controls_actions() {
		add_action( 'elementor/element/tm-ele-block-features/general/after_section_end', [ $this, 'register_layout_controls' ] );
	}

	public function get_id() {
		return 'skin-style2';
	}


	public function get_title() {
		return __( 'Skin Style2', 'mascot-core-tranxpress' );
	}


	public function register_layout_controls( Widget_Base $widget ) {
		$this->parent = $widget;

		//Feature Block Skin2 Content
		$this->start_controls_section(
			'feature_skin2_content',
			[
				'label' => esc_html__( 'Feature Contnet', 'mascot-core-tranxpress' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'arrow_image',
			[
				'label' => esc_html__( "Arrow Image", 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				"description" => esc_html__( "Upload arrow image", 'mascot-core-tranxpress' ),
			]
		);
		$this->add_control(
			'arrow_image_size', [
				'label' => esc_html__( "Arrow Image Size", 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_get_available_image_sizes(),
				'default' => 'thumbnail',
			]
		);

		$this->end_controls_section();

		//Current Feature Styling
		$this->start_controls_section(
			'current_feature_styling',
			[
				'label' => esc_html__( 'Current Feature Styling', 'mascot-core-tranxpress' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->start_controls_tabs('tabs_current_style');
		$this->start_controls_tab(
			'tabs_current_style_normal',
			[
				'label' => esc_html__('Normal', 'mascot-core-tranxpress'),
			]
		);
		// Feature Background Options
		$this->add_control(
			'feature_block_backgroun_options',
			[
				'label' => esc_html__( 'Background Options', 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_background_color',
			[
				'label' => esc_html__( "Background Color", 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box .icon-box' => 'background-color: {{VALUE}};',
				]
			]
		);
		// Feature Icon Options
		$this->add_control(
			'feature_block_icon_options',
			[
				'label' => esc_html__( 'Icon Options', 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_icon_color',
			[
				'label' => esc_html__( "Custom Icon Color", 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box .icon-box .icon i' => 'color: {{VALUE}};',
				]
			]
		);
		// Feature Title Options
		$this->add_control(
			'feature_block_title_options',
			[
				'label' => esc_html__( 'Title Options', 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_control(
			'title_text_color',
			[
				'label' => esc_html__( "Title Color", 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box .feature-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_theme_colored',
			[
				'label' => esc_html__( "Title Theme Colored", 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box .feature-title' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => esc_html__( 'Typography', 'mascot-core-tranxpress' ),
				'selector' => '{{WRAPPER}} .feature-current-item-style2 .inner-box .feature-title',
			]
		);
		$this->add_responsive_control(
			'title_margin',
			[
				'label' => esc_html__( 'Title Margin', 'mascot-core-tranxpress' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box .feature-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'title_padding',
			[
				'label' => esc_html__( 'Title Padding', 'mascot-core-tranxpress' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box .feature-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		// Feature Content Options
		$this->add_control(
			'feature_block_content_options',
			[
				'label' => esc_html__( 'Content Options', 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_control(
			'content_text_color',
			[
				'label' => esc_html__( "Content Color", 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box .feature-details' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();


		$this->start_controls_tab(
			'tabs_current_style_hover',
			[
				'label' => esc_html__('Hover', 'mascot-core-tranxpress'),
			]
		);
		// Feature Background Options
		$this->add_control(
			'feature_block_backgroun_hover_options',
			[
				'label' => esc_html__( 'Background Options', 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_background_hover_color',
			[
				'label' => esc_html__( "Background Color", 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box:hover .icon-box' => 'background-color: {{VALUE}};',
				]
			]
		);
		// Feature Icon Options
		$this->add_control(
			'feature_block_icon_hover_options',
			[
				'label' => esc_html__( 'Icon Options', 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_icon_hover_color',
			[
				'label' => esc_html__( "Custom Icon Hover Color", 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box:hover .icon-box .icon i' => 'color: {{VALUE}};',
				]
			]
		);
		// Feature Title Options
		$this->add_control(
			'feature_block_title_hover_options',
			[
				'label' => esc_html__( 'Title Options', 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_control(
			'title_text_hover_color',
			[
				'label' => esc_html__( "Text Hover Color", 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box:hover .feature-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_hover_theme_colored',
			[
				'label' => esc_html__( "Title Hover Theme Colored", 'mascot-core-tranxpress' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box:hover .feature-title' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();

	}

	public function render() {
		$settings = $this->parent->get_settings_for_display();

		//link url
		$settings['target'] = ( $settings['link'] && $settings['link']['is_external'] ) ? ' target="_blank"' : '';
		$settings['url'] = ( $settings['link'] && $settings['link']['url'] ) ? $settings['link']['url'] : '';



		//classes
		$classes = array();
		$classes[] = $settings['custom_css_class'];

		if( $settings['animate_icon_on_hover'] ) {
			$classes[] = 'animate-icon-on-hover animate-icon-'.$settings['animate_icon_on_hover'];
		}
		$settings['classes'] = $classes;

		//enqueue css
		$direction_suffix = is_rtl() ? '.rtl' : '';
		wp_enqueue_style( 'tm-block-feature-current-item-style2', MASCOT_CORE_TRANXPRESS_URL_PATH . 'assets/css/shortcodes/block-features/block-feature-current-item-style2' . $direction_suffix . '.css' );

		//classes


		//icon classes
		$icon_classes = array();
		$settings['icon_classes'] = $icon_classes;

		//button classes
		$settings['btn_classes'] = mascot_core_prepare_button_classes_from_params( $settings );

		//title classes
		$title_classes = array();
		$settings['title_classes'] = $title_classes;

		//subtitle classes
		$subtitle_classes = array();
		$settings['subtitle_classes'] = $subtitle_classes;

		//icon classes
		$icon_classes = array();
		$settings['icon_classes'] = $icon_classes;

		$settings['settings'] = $settings;

		//Produce HTML version by using the parameters (filename, variation, folder name, parameters, shortcode_ob_start)
		$html = mascot_core_tranxpress_get_shortcode_template_part( 'block-features-' . $settings['_skin'], null, 'block-features/tpl', $settings, true );

		echo $html;
	}
}